Enum libreda_sta::StaError
source · pub enum StaError {
PinNotFoundInNetlist(String, String),
MissingCellsInLiberty(Vec<String>),
BadNetlist,
CombinationalCycle,
NoClockDefined,
Other(String),
}Expand description
Error during static timing analysis. This includes errors in the liberty library, mismatches between netlist and library or invalid netlists (drive conflicts, etc).
Variants
PinNotFoundInNetlist(String, String)
Pin is referenced in the library but not present in the netlist.
MissingCellsInLiberty(Vec<String>)
Some cells used in the netlist cannot be found in the liberty library.
BadNetlist
Something is bad with the netlist. This includes drive conflicts, floating input pins, etc.
CombinationalCycle
Circuit contains a combinational cycle.
NoClockDefined
No clock source is defined.
Other(String)
Unspecified error.