pub(crate) fn compute_net_loads<N: NetlistBase, Lib: CellLoadModel<N>>(
    top: &CellRef<'_, N>,
    library: &Lib
) -> FnvHashMap<N::NetId, Lib::Load>
Compute total net capacitances for each net of the top circuit. Simply sums up the input capacitances of all connected input pins for each net.