pub(crate) struct TimingGraphDot<'a, N, T>where
    T: ConstraintBase,
    N: NetlistBase,{
    config: TimingGraphDotConfig,
    netlist: &'a N,
    timing_graph: &'a TimingGraph<N, T>,
}
Wrapper struct for printing a timing graph in the Graphviz Dot-format. This struct’s implementation of Debug prints the timing graph in the Dot-format.

Fields

config: TimingGraphDotConfig

Netlist is needed to resolve the names of pins and nets.

netlist: &'a Ntiming_graph: &'a TimingGraph<N, T>

Implementations

source

impl<'a, N, T> TimingGraphDot<'a, N, T>where T: ConstraintBase, T::Signal: Debug, N: NetlistBase,

source

fn dot_format(&self, f: &mut Formatter<'_>) -> Result

Format the timing graph as a DOT digraph. This is intended for debugging.

source

impl<'a, N: NetlistBase, T: ConstraintBase> TimingGraphDot<'a, N, T>

source

pub fn new(timing_graph: &'a TimingGraph<N, T>, netlist: &'a N) -> Self

Create a Graphviz formatter for the timing graph.

The netlist is needed to resolve pin/net names. Passing another netlist than used for building the timing graph might lead to a panic during formatting.

source

pub fn new_with_config( timing_graph: &'a TimingGraph<N, T>, netlist: &'a N, config: TimingGraphDotConfig ) -> Self

Create a Graphviz formatter for the timing graph.

The netlist is needed to resolve pin/net names. Passing another netlist than used for building the timing graph might lead to a panic during formatting.