Enum libreda_sta::liberty_library::TimingType
source · pub enum TimingType {
Show 21 variants
Combinational,
CombinationalRise,
CombinationalFall,
ThreeStateDisable,
ThreeStateEnable,
ThreeStateDisableRise,
ThreeStateDisableFall,
ThreeStateEnableRise,
ThreeStateEnableFall,
RisingEdge,
FallingEdge,
Preset,
Clear,
HoldRising,
HoldFalling,
SetupRising,
SetupFalling,
RecoveryRising,
RecoveryFalling,
RemovalRising,
RemovalFalling,
}Expand description
Liberty timing type.
Variants
Combinational
CombinationalRise
CombinationalFall
ThreeStateDisable
ThreeStateEnable
ThreeStateDisableRise
ThreeStateDisableFall
ThreeStateEnableRise
ThreeStateEnableFall
RisingEdge
Output pin is sensitive to rising edge of related signal.
FallingEdge
Output pin is sensitive to falling edge of related signal.
Preset
Asynchronous set.
Clear
Asynchronous clear/reset.
HoldRising
Hold arc which is sensitive to rising edge at related pin.
HoldFalling
Hold arc which is sensitive to falling edge at related pin.
SetupRising
Setup arc which is sensitive to rising edge at related pin.
SetupFalling
Setup arc which is sensitive to falling edge at related pin.
RecoveryRising
RecoveryFalling
RemovalRising
RemovalFalling