fn get_interpolated_timing_table(
    timing_group: &Group,
    table_group: &Group,
    table_templates: &HashMap<String, LuTableTemplate>,
    required_var1_name: &str,
    required_var2_name: &str,
    cell_name: &str,
    pin_name: &str
) -> Result<Interp, LibertyErr>
Read a lookup table with indices and put it into an interpolator struct such that the lookup table can be evaluated like a function.

  • required_var1_name: The name of the variable which should be used as first variable in the interpolated function.
  • required_var2_name: The name of the variable which should be used as second variable in the interpolated function.
  • cell_name: Name of the cell. Used for log output.
  • pin_name: Name of the pin. Used for log output.