Enum libreda_sta::liberty_util::LibertyErr
source · pub enum LibertyErr {
AttributeNotFound(String),
TableMalformed,
TableNotFound(String),
InvalidLuTableTemplate(String),
UnsupportedDelayModel(String),
UnitNotDefined(&'static str),
Other(String),
}Expand description
Describes errors that happen when accessing a liberty library.
Variants
AttributeNotFound(String)
An attribute could not be found.
TableMalformed
A table was malformed: Not a float array or wrong sizes of rows for 2D arrays.
TableNotFound(String)
Table with this name was not found.
InvalidLuTableTemplate(String)
Something is wrong with a lookup table template.
UnsupportedDelayModel(String)
The specified delay model is not supported or no delay model is specified.
UnitNotDefined(&'static str)
The library does not define a required unit (time, capacitance, …).
Other(String)
Unspecified error.