pub fn select_timing_groups<'a>(
    pin_group: &'a Group,
    related_pin: &str,
    timing_type: &str
) -> Vec<&'a Group>
Find timing groups within a pin group by the name of the related pin and the timing type.