Module libreda_sta::models::clock_tag

source ·
Wrap delay/constraint models and add the capability to tag signals with an associated clock.

Structs

  • Wrapper around interconnect delay models.
  • Wrap a delay and/or constraint model and add the capability of tracking clock sources.
  • Compact ID for marking signals with a clock.
  • Signal representation wich can keep track of the clock(s) which launch the signal transition.