Struct libreda_sta::models::clock_tag::ClockAwareInterconnectModel
source · pub struct ClockAwareInterconnectModel<M> { /* private fields */ }Expand description
Wrapper around interconnect delay models.
Used to keep the link between signals and their clock domains. The data-structure is zero-cost for the interconnect model. The data-structure for the signals gets larger because of the additional clock ID.
Implementations
sourceimpl<M> ClockAwareInterconnectModel<M>
impl<M> ClockAwareInterconnectModel<M>