Struct libreda_sta::models::clock_tag::ClockAwareModel

source ·
pub struct ClockAwareModel<M> { /* private fields */ }
Wrap a delay and/or constraint model and add the capability of tracking clock sources.

Implementations

source

impl<M> ClockAwareModel<M>

source

pub fn new(inner_model: M) -> Self

Wrap a cell delay model.

source

pub fn create_primary_clock(&mut self, period: Time, jitter: Time) -> ClockId

Register a clock. Returns an ID which can be used for labelling signals with this clock.