Enum libreda_sta::models::ndlm_cell_delay::DelayModelType
source · pub enum DelayModelType {
Constant(Time),
NDLM,
}Expand description
Specify what delay model to use. This implementation of the NDLM delay model can also fall back to a constant delay model.
Variants
Constant(Time)
Use the same constant delay for all delay arcs. Used for example for levelization.
NDLM
Use the non-linear delay model.