Function libreda_sta::models::ndlm_cell_delay::convert_edge_polarity
source · fn convert_edge_polarity(
edge_polarity: EdgePolarity
) -> SmallVec<[EdgePolarity; 2]>Expand description
Resolve the edge polarities which need to be respected. An unknown polarity is translated to two polarities “rise” and “fall”.