pub struct NDLMCellModel<'a, N: NetlistBase> {
    sta_mode: StaMode,
    delay_model_type: DelayModelType,
    library: &'a LibertyTimingLibrary<'a>,
    pin_capacitances: FnvHashMap<N::PinId, NDLMOutputLoad>,
    pin_data: FnvHashMap<N::PinId, &'a Pin>,
    ordered_pins: FnvHashMap<N::CellId, Vec<N::PinId>>,
    warn_negative_slew: Once,
    warn_negative_delay: Once,
}
Parameters

'a: Lifetime of the liberty library.

Fields

sta_mode: StaModedelay_model_type: DelayModelType

Choose between using NDLM or a constant delay.

library: &'a LibertyTimingLibrary<'a>pin_capacitances: FnvHashMap<N::PinId, NDLMOutputLoad>

Table for quickly finding the input capacitance of a pin. Capacitance is available also in pin_data but access might be faster using this field.

pin_data: FnvHashMap<N::PinId, &'a Pin>

Lookup-table for pin data (capacitance, delay arcs, constraint arcs, …).

ordered_pins: FnvHashMap<N::CellId, Vec<N::PinId>>

Cache the pin ordering for all the cells.

warn_negative_slew: Once

Warn once about negative slew.

warn_negative_delay: Once

Implementations

source

impl<'a, N: NetlistBase> NDLMCellModel<'a, N>

source

pub fn new(library: &'a LibertyTimingLibrary<'_>, netlist: &N) -> Self

Create a new NDLM cell model based on a liberty library.

source

pub fn set_delay_model_type(&mut self, model_type: DelayModelType)

Choose between NDLM and constant delays.

source

fn init(&mut self, netlist: &N)

source

fn init_capacitance_table(&mut self, netlist: &N)

Create a lookup-table for the default pin capacitances.