pub struct NDLMSignal {
    edge_polarity: EdgePolarity,
    slew: [Time; 4],
    delay: [Time; 4],
    logic_value: Logic3,
}
Slew rate and edge polarity of a signal.

Fields

edge_polarity: EdgePolarity

Type of the transition.

slew: [Time; 4]

Transition times for: min-rise, min-fall, max-rise, max-fall

delay: [Time; 4]

Arrival times for: min-rise, min-fall, max-rise, max-fall

logic_value: Logic3

Logic value on which the signal stabilizes.

Implementations

source

impl NDLMSignal

source

pub fn new(slew_rate: Time, arrival_time: Time) -> Self

Create a new signal with a given arrival time. Other values are set to defaults.

source

pub fn set_polarity(&mut self, edge_polarity: EdgePolarity)

Set the polarity of the signal transition. Default is EdgePolarity::Unknown.

source

pub fn with_polarity(self, edge_polarity: EdgePolarity) -> Self

Set the polarity of the signal transition. Default is EdgePolarity::Unknown.

source

pub fn slew(&self, minmax: MinMax, edge: RiseFall) -> Time

Get the minimum/maximum slew for the rise or fall edge.

source

fn max_slew(&self) -> Time

source

fn min_slew(&self) -> Time

source

fn max_delay(&self) -> Time

source

fn min_delay(&self) -> Time

source

pub fn delay(&self, minmax: MinMax, edge: RiseFall) -> Time

Get the minimum/maximum delay for the rise or fall edge.

source

fn slew_mut(&mut self, minmax: MinMax, edge: RiseFall) -> &mut Time

source

fn delay_mut(&mut self, minmax: MinMax, edge: RiseFall) -> &mut Time

source

pub fn set_slew_rates(&mut self, slew_rate: Time)

Set the slew rate for all corners.

source

pub fn set_arrival_times(&mut self, arrival_time: Time)

Set the arrival times for all corners.

source

pub fn set_slew_rate(&mut self, corner: MinMax, edge: RiseFall, slew_rate: Time)

Set the slew rate for the specified corner and transition type.

source

pub fn set_arrival_time( &mut self, corner: MinMax, edge: RiseFall, arrival_time: Time )

Set the slew rate for the specified corner and transition type.

source

fn acc_arrival_time(&mut self, edge: RiseFall, arrival_time: Time)

Accumulate arrival time.

source

fn acc_slew(&mut self, edge: RiseFall, slew: Time)

Accumulate transition time.

source

pub fn set_logic_value(self, value: Logic3)

Set the logic value of the signal (after transition).

source

pub fn with_slew_rates(self, slew_rate: Time) -> Self

Set the slew rate for all corners.

source

pub fn with_arrival_times(self, arrival_time: Time) -> Self

Set the arrival times for all corners.

source

pub fn with_slew_rate( self, corner: MinMax, edge: RiseFall, slew_rate: Time ) -> Self

Set the slew rate for the specified corner and transition type.

source

pub fn with_arrival_time( self, corner: MinMax, edge: RiseFall, arrival_time: Time ) -> Self

Set the slew rate for the specified corner and transition type.

source

pub fn with_logic_value(self, value: Logic3) -> Self

Set the logic value of the signal (after transition).