Module zero_interconnect_delay

Module zero_interconnect_delay 

Dummy implementation of an interconnect delay model: The delay is always zero.

Structs

ZeroInterconnectDelayModel
Interconnect delay model which reports zero delay for a source and target terminal which belong to the same net and ‘no delay’ if the terminals don’t belong to the same net.