pub struct ZeroInterconnectDelayModel<'a, D> {
delay_model: &'a D,
}Expand description
Interconnect delay model which reports zero delay for a source and target terminal which belong to the same net and ‘no delay’ if the terminals don’t belong to the same net.
Fields
delay_model: &'a DImplementations