Struct libreda_sta::ClockDefinition
source · pub struct ClockDefinition<Signal> {
pub(crate) period: Time,
pub(crate) first_edge: Signal,
pub(crate) second_edge: Signal,
}Expand description
Definition of a clock source.
Fields
period: TimePeriod of the clock signal.
first_edge: SignalRepresentation of the first edge of a clock cycle.
The Signal datatype typically encodes phase and slope.
second_edge: SignalRepresentation of the second edge of a clock cycle.
The Signal datatype typically encodes phase and slope.
Must have the opposite polarity of the first edge.
Implementations