Struct libreda_sta::SimpleSTA

source ·
pub struct SimpleSTA<'a, N, Lib, State>where
    N: NetlistBase,
    Lib: DelayBase + LoadBase + ConstraintBase,{
    pub(crate) netlist: N,
    pub(crate) top_cell: N::CellId,
    pub(crate) library: &'a Lib,
    pub(crate) input_signals: HashMap<N::PinId, Lib::Signal>,
    pub(crate) output_loads: HashMap<N::PinId, Lib::Load>,
    pub(crate) required_output_signals: HashMap<N::PinId, Lib::RequiredSignal>,
    pub(crate) clocks: HashMap<TerminalId<N>, ClockDefinition<Lib::Signal>>,
    pub(crate) timing_graph: TimingGraph<N, Lib>,
    pub(crate) generation: u32,
    pub(crate) _netlist_type: PhantomData<N>,
    pub(crate) _state: PhantomData<State>,
}
Simple static timing analysis engine.

Fields

netlist: Ntop_cell: N::CellIdlibrary: &'a Libinput_signals: HashMap<N::PinId, Lib::Signal>output_loads: HashMap<N::PinId, Lib::Load>required_output_signals: HashMap<N::PinId, Lib::RequiredSignal>clocks: HashMap<TerminalId<N>, ClockDefinition<Lib::Signal>>timing_graph: TimingGraph<N, Lib>generation: u32

Count the number of timing updates. Used to efficiently mark nodes in the timing graph which are relevant for the current incremental upgrade. Used to distinguish between the first full update (needs more initialization) and subsequent incremental updates.

_netlist_type: PhantomData<N>_state: PhantomData<State>

Implementations

source

impl<'a, N, Lib, S> SimpleSTA<'a, N, Lib, S>where N: NetlistBase, Lib: DelayBase + ConstraintBase,

source

pub fn into_inner(self) -> N

Get ownership of the netlist data.

source

pub(crate) fn netlist(&self) -> &N

Shortcut to get the reference to the netlist.

source

pub(crate) fn top_cell_ref(&self) -> CellRef<'_, N>

source

impl<'a, N, Lib> SimpleSTA<'a, N, Lib, TimingAvailable>where N: NetlistBase, Lib: DelayBase + ConstraintBase,

source

pub fn to_modifiable(self) -> SimpleSTA<'a, N, Lib, Modifiable>

Convert to modifiable state. Call this function to modify the timing analysis settings or the netlist.

source

impl<'a, N, Lib> SimpleSTA<'a, N, Lib, Modifiable>where N: NetlistBaseMT, Lib: CellLoadModel<N> + CellDelayModel<N> + CellConstraintModel<N> + Sync,

source

pub fn update_timing( self ) -> Result<SimpleSTA<'a, N, Lib, TimingAvailable>, (StaError, Self)>

Compute the timing information. On success, returns the STA engine in TimingAvailable mode where timing queries are enabled. On error, returns a tuple with an error code and the STA engine in Modifiable mode.

source

impl<'a, N, Lib> SimpleSTA<'a, N, Lib, Modifiable>where N: NetlistBase, Lib: CellLoadModel<N> + CellDelayModel<N> + CellConstraintModel<N>,

source

pub fn new( netlist: N, top_cell: N::CellId, cell_timing_library: &'a Lib ) -> Result<Self, StaError>

Create a new static timing analysis engine which analyzes the given netlist using timing information of the cells from the given library.

source

pub(crate) fn init(&mut self) -> Result<(), StaError>

source

pub fn set_input_signal( &mut self, primary_input: N::PinId, signal: Lib::Signal ) -> Result<(), StaError>

Set the signal at a primary input.

source

pub fn set_output_load( &mut self, primary_output: N::PinId, load: Lib::Load ) -> Result<(), StaError>

Set the load attached to a primary output.

source

pub fn set_required_output_signal( &mut self, primary_output: N::PinId, required_signal: Lib::RequiredSignal ) -> Result<(), StaError>

Specify the timing constraint of a primary output.

source

pub fn create_clock( &mut self, clock_pin: TerminalId<N>, clock_definition: ClockDefinition<Lib::Signal> ) -> Result<(), StaError>

Specify a clock source.

source

pub(crate) fn build_timing_graph(&mut self) -> Result<(), StaError>

Create graph of delay arcs.

source

pub(crate) fn init_input_signals(&mut self) -> Result<(), StaError>

Copy the defined input signals into the nodes of the timing graph.

source

pub(crate) fn init_required_output_signals(&mut self) -> Result<(), StaError>

Copy the specified output signals into the timing graph.

source

pub(crate) fn init_output_loads(&mut self) -> Result<(), StaError>

Copy the specified output loads into the timing graph.

source

pub(crate) fn init_clock_signals(&mut self) -> Result<(), StaError>

source

pub(crate) fn propagate_signals( &mut self, net_loads: &FnvHashMap<N::NetId, Lib::Load> ) -> Result<(), StaError>where Lib: Sync, N: NetlistBaseMT,

Compute actual and required arival times.

source

pub(crate) fn toposort_delay_graph( &self ) -> Result<Vec<TerminalId<N>>, StaError>

source

pub(crate) fn debug_print_actual_signals(&self)

source

pub(crate) fn debug_print_timing_graph(&self)

source

pub(crate) fn run_sta(&mut self) -> Result<(), StaError>where Lib: Sync, N: NetlistBaseMT,

Do static timing analysis of the top cell. A single clock is allowed and specified with clock_input. Results are just printed on stdout.

source

pub(crate) fn check_library(&self) -> Result<(), StaError>

Check that all cells in the circuit are covered by the library. TODO: Maybe move this into the library adapter.

source

pub(crate) fn check_clock_sources(&self) -> Result<(), StaError>

Do some sanity checks.