pub(crate) enum GraphNodeType<N: NetlistIds> {
    ForwardPropagationSource,
    BackwardPropagationSource,
    Terminal(TerminalId<N>),
}
Node in the timing graph. Most nodes represent a pin in the netlist. There are also a few virtual nodes (source nodes) which simplify the implementation of the delay propagation algorithms.

Variants



ForwardPropagationSource

A virtual node. Used as a start node in the delay propagation algorithm.



BackwardPropagationSource

A virtual node which represents the starting node for backpropagating the constraints.



Terminal(TerminalId<N>)

A node which represents a pin of a circuit component. Most of the nodes will be of this variant.