Struct libreda_sta::timing_graph::DependencyCounter
source · pub(crate) struct DependencyCounter {
num_unresolved: AtomicU32,
}Expand description
Atomic counter unresolved dependencies of graph nodes.
Fields
num_unresolved: AtomicU32Number of unresolved dependencies.
Implementations
sourceimpl DependencyCounter
impl DependencyCounter
sourcepub fn num_unresolved(&self) -> u32
pub fn num_unresolved(&self) -> u32
Get number of unresolved dependencies. Loaded using relaxed memory ordering.
sourcepub fn set_num_unresolved(&self, num_unresolved: u32)
pub fn set_num_unresolved(&self, num_unresolved: u32)
Set the number of unresolved dependencies. Uses relaxed memory ordering.
sourcepub fn increment_unresolved(&self) -> u32
pub fn increment_unresolved(&self) -> u32
Increment the number of unresolved dependencies and return the result.
sourcepub fn decrement_unresolved(&self) -> u32
pub fn decrement_unresolved(&self) -> u32
Decrement the number of unresolved dependencies and return the result.
Panics
Panics on an integer underflow.