Struct libreda_sta::timing_graph::SyncEdgeData
source · pub(crate) struct SyncEdgeData<D>where
D: TimingBase + ConstraintBase,{
pub delay: Option<D::Delay>,
pub constraint: Option<D::Constraint>,
}Expand description
Edge data which we can access during parallel graph operations.
Access to this data is synchronized by a lock in the DataCell struct.
Fields
delay: Option<D::Delay>constraint: Option<D::Constraint>Trait Implementations
sourceimpl<D> Clone for SyncEdgeData<D>where
D: TimingBase + ConstraintBase + Clone,
D::Delay: Clone,
D::Constraint: Clone,
impl<D> Clone for SyncEdgeData<D>where D: TimingBase + ConstraintBase + Clone, D::Delay: Clone, D::Constraint: Clone,
sourcefn clone(&self) -> SyncEdgeData<D>
fn clone(&self) -> SyncEdgeData<D>
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read more