Struct libreda_sta::timing_graph::SyncNodeData
source · pub(crate) struct SyncNodeData<D>where
D: TimingBase + ConstraintBase,{
pub is_primary_input: bool,
pub signal: Option<D::Signal>,
pub required_signal: Option<D::RequiredSignal>,
}Expand description
Node data which we can access during parallel graph operations.
Access to this data is synchronized by a lock in the DataCell struct.
Fields
is_primary_input: boolMark this node as a primary input. Primary inputs have the actual signal set by the user. The actual signal of a primary input thus does not need to be computed.
signal: Option<D::Signal>The signal at this location in the netlist. This is typically used to represent the arrival time.
required_signal: Option<D::RequiredSignal>The required signal which is necessary to meet constraints in the netlist. Typically this is encodes the required arrival time.