Module libreda_sta::traits

source ·
Traits for abstracting timing models.

Types for actual signals, output loads, delays, required signals and constraints are kept abstract. The idea is to be able to use the same architecture for simple timing models such as the non-linear delay model (NDLM) but also for more complicated methods like statistical timing analysis. In the latter case a signal type would for example not only consist of a delay and a slew rate but represent a probability distribution thereof.

Re-exports

Modules

Traits