pub trait CellLoadModel<N: NetlistBase>: TimingBase + LoadBase + CellModel<N> {
    // Required methods
    fn input_pin_load(
        &self,
        input_pin: &N::PinId,
        other_inputs: &impl Fn(&N::PinId) -> Option<Self::LogicValue>
    ) -> Self::Load;
    fn zero(&self) -> Self::Load;
}
Abstraction of electrical loads created by input pins.

Required Methods

source

fn input_pin_load( &self, input_pin: &N::PinId, other_inputs: &impl Fn(&N::PinId) -> Option<Self::LogicValue> ) -> Self::Load

Get the load created by a pin, typically its capacitance.

source

fn zero(&self) -> Self::Load

Return a value representing no load at all (zero capacitance for example).

Implementors

source

impl<'a, N: NetlistBase> CellLoadModel<N> for NDLMCellModel<'a, N>