#[non_exhaustive]pub enum OutputFunction<PinId> {
Unknown,
Comb(BooleanFn<PinId>),
Sequential(Sequential<PinId>),
}Expand description
Either a combinational/boolean function or a state-holding element.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Unknown
The output function of the pin is not known.
Comb(BooleanFn<PinId>)
Combinational logic: The value of the output pin is defined by a boolean function.
Sequential(Sequential<PinId>)
Sequential logic: The value of the output pin is defined by a state-holding element.