Struct libreda_sta::traits::cell_logic_model::Sequential
source · pub struct Sequential<PinId> {
pub clocked_on: Vec<BooleanExpr<PinId>>,
pub transparent_on: Vec<BooleanExpr<PinId>>,
}Expand description
Description of an output pin which is driven by a sequential circuit.
Fields
clocked_on: Vec<BooleanExpr<PinId>>The sequential output is updated when at least one
of the boolean expressions transitions from false to true.
transparent_on: Vec<BooleanExpr<PinId>>TODO: Latches: