Struct libreda_sta::graphviz::TimingGraphDot
source · pub(crate) struct TimingGraphDot<'a, N, T>where
T: ConstraintBase,
N: NetlistBase,{
config: TimingGraphDotConfig,
netlist: &'a N,
timing_graph: &'a TimingGraph<N, T>,
}Expand description
Wrapper struct for printing a timing graph in the Graphviz Dot-format.
This struct’s implementation of Debug prints the timing graph in the Dot-format.
Fields
config: TimingGraphDotConfigNetlist is needed to resolve the names of pins and nets.
netlist: &'a Ntiming_graph: &'a TimingGraph<N, T>Implementations
sourceimpl<'a, N, T> TimingGraphDot<'a, N, T>where
T: ConstraintBase,
T::Signal: Debug,
N: NetlistBase,
impl<'a, N, T> TimingGraphDot<'a, N, T>where T: ConstraintBase, T::Signal: Debug, N: NetlistBase,
sourcefn dot_format(&self, f: &mut Formatter<'_>) -> Result
fn dot_format(&self, f: &mut Formatter<'_>) -> Result
Format the timing graph as a DOT digraph. This is intended for debugging.
sourceimpl<'a, N: NetlistBase, T: ConstraintBase> TimingGraphDot<'a, N, T>
impl<'a, N: NetlistBase, T: ConstraintBase> TimingGraphDot<'a, N, T>
sourcepub fn new(timing_graph: &'a TimingGraph<N, T>, netlist: &'a N) -> Self
pub fn new(timing_graph: &'a TimingGraph<N, T>, netlist: &'a N) -> Self
Create a Graphviz formatter for the timing graph.
The netlist is needed to resolve pin/net names. Passing another netlist
than used for building the timing graph might lead to a panic during formatting.
sourcepub fn new_with_config(
timing_graph: &'a TimingGraph<N, T>,
netlist: &'a N,
config: TimingGraphDotConfig
) -> Self
pub fn new_with_config( timing_graph: &'a TimingGraph<N, T>, netlist: &'a N, config: TimingGraphDotConfig ) -> Self
Create a Graphviz formatter for the timing graph.
The netlist is needed to resolve pin/net names. Passing another netlist
than used for building the timing graph might lead to a panic during formatting.