Trait libreda_sta::levelization::AtomicNodeLevel
source · pub trait AtomicNodeLevel {
// Required method
fn node_level(&self) -> &AtomicU32;
}Expand description
Get a reference to an atomic variable which represents the level of a node. Used as an indirection to make the levelization algorithm more generic.