Struct libreda_sta::liberty_library::LibertyTimingLibrary
source · pub struct LibertyTimingLibrary<'a> {
pub(crate) lib: &'a Group,
table_templates: HashMap<String, LuTableTemplate>,
time_unit: Time,
capacitive_load_unit: Capacitance,
pub(crate) cells: HashMap<String, Cell>,
}Expand description
Timing library based on a ‘liberty’ library.
Fields
lib: &'a GroupLiberty library group.
table_templates: HashMap<String, LuTableTemplate>time_unit: Timecapacitive_load_unit: Capacitancecells: HashMap<String, Cell>Mapping from (cell_name, pin_name, related_pin_name) to the delay arc structure.
Implementations
sourceimpl<'a> LibertyTimingLibrary<'a>
impl<'a> LibertyTimingLibrary<'a>
sourcepub fn new(lib: &'a Group) -> Result<Self, LibertyErr>
pub fn new(lib: &'a Group) -> Result<Self, LibertyErr>
Create a new timing library based on a liberty structure.
sourcefn init_units(&mut self) -> Result<(), LibertyErr>
fn init_units(&mut self) -> Result<(), LibertyErr>
Load units from the liberty data structure.
sourcepub fn get_pin(&self, cell: &str, output_pin: &str) -> Option<&Pin>
pub fn get_pin(&self, cell: &str, output_pin: &str) -> Option<&Pin>
Find a pin by the name of the cell and the name of the pin.
pub(crate) fn get_delay_arc( &self, cell: &str, output_pin: &str, related_pin: &str ) -> Option<&DelayArc>
pub(crate) fn get_hold_rising_arc( &self, cell: &str, output_pin: &str, related_pin: &str ) -> Option<&ConstraintArc>
pub(crate) fn get_hold_falling_arc( &self, cell: &str, output_pin: &str, related_pin: &str ) -> Option<&ConstraintArc>
pub(crate) fn get_setup_rising_arc( &self, cell: &str, output_pin: &str, related_pin: &str ) -> Option<&ConstraintArc>
pub(crate) fn get_setup_falling_arc( &self, cell: &str, output_pin: &str, related_pin: &str ) -> Option<&ConstraintArc>