Struct libreda_sta::liberty_library::Pin
source · pub struct Pin {
pub(crate) capacitance: Capacitance,
pub(crate) delay_arcs: HashMap<String, DelayArc>,
pub(crate) hold_rising: HashMap<String, ConstraintArc>,
pub(crate) hold_falling: HashMap<String, ConstraintArc>,
pub(crate) setup_rising: HashMap<String, ConstraintArc>,
pub(crate) setup_falling: HashMap<String, ConstraintArc>,
}Expand description
Timing information of an output pin.
Fields
capacitance: CapacitanceInput capacitance of the pin.
delay_arcs: HashMap<String, DelayArc>Mapping from related pin name to the delay/slew values.
hold_rising: HashMap<String, ConstraintArc>Hold constraints relative to rising clock edges. Mapping from related pin name to the constraint values.
hold_falling: HashMap<String, ConstraintArc>Hold constraints relative to falling clock edges. Mapping from related pin name to the constraint values.
setup_rising: HashMap<String, ConstraintArc>Setup constraints relative to rising clock edges. Mapping from related pin name to the constraint values.
setup_falling: HashMap<String, ConstraintArc>Setup constraints relative to falling clock edges. Mapping from related pin name to the constraint values.