Function libreda_sta::liberty_util::get_timing_table
source · pub fn get_timing_table(
timing_group: &Group,
table_name: &str,
index_1_name: &str,
index_2_name: &str,
values_name: &str
) -> Result<Interp<f64>, LibertyErr>Expand description
Read a two dimensional table with indices and create an Interp2D struct out of them.
The timing_group must be an actual timing liberty group. Otherwise this function panics.
table_name is the liberty group name of the table (cell_rise, rise_transition, …).
The indices must be attributes with names index_1_name and index_2_name, the values must be an attribute
with name values_name.