Function libreda_sta::liberty_util::select_timing_groups
source · pub fn select_timing_groups<'a>(
pin_group: &'a Group,
related_pin: &str,
timing_type: &str
) -> Vec<&'a Group>Expand description
Find timing groups within a pin group by the name of the related pin and the timing type.