Struct libreda_sta::models::clock_tag::ClockId

source ·
pub struct ClockId { /* private fields */ }
Compact ID for marking signals with a clock.

Identifier for clocks, generated clocks, propagated clocks, inverted clocks, etc. This struct is a wrapper around a 32-bit integer. It is used as an efficient marker to associate nets with a clock source.

Implementations

source

impl ClockId

source

pub fn new(storage_index: u32) -> Self

Create a new clock ID from the index of the clock. The index is a ‘pointer’ to the specification of the clock. The ID is used to annotate signals in order to link them to a clock source. The ID does not only store this index but also keeps track of other properties such as on which clock events the signal can change.

source

pub fn storage_index(&self) -> usize

Get the index into the array of clocks. Points to the detailed description of the corresponding clock.

source

pub fn is_inverted(&self) -> bool

Check if this ID refers to an inverted version of the clock.

source

pub fn is_clock(&self) -> bool

Test if this signal is marked as a clock signal. This flag gets cleared when a clock signal passes through a clock input of a sequential cell to a data output.

source

pub fn set_clock(&mut self, is_clock: bool)

Define if this signal is a clock or just a clocked signal otherwise.

source

pub fn inverted(&self) -> Self

Get the ID of the inverted clock.

source

pub fn is_sensitive_on_edge(&self, edge_type: RiseFall) -> bool

For actual signals: Test if the signal can change on the given edge type of the associated clock. For required signals: Test if the constraint applies to the given edge type of the associated clock.

source

pub fn set_edge_sensitivity(&mut self, edge_type: RiseFall, can_change: bool)

For actual signals: Define if the signal annotated with this ID can change on the given clock edge.