Struct libreda_sta::models::ndlm_cell_delay::NDLMCellModel
source · pub struct NDLMCellModel<'a, N: NetlistBase> {
sta_mode: StaMode,
delay_model_type: DelayModelType,
library: &'a LibertyTimingLibrary<'a>,
pin_capacitances: FnvHashMap<N::PinId, NDLMOutputLoad>,
pin_data: FnvHashMap<N::PinId, &'a Pin>,
ordered_pins: FnvHashMap<N::CellId, Vec<N::PinId>>,
warn_negative_slew: Once,
warn_negative_delay: Once,
}Expand description
Parameters
'a: Lifetime of the liberty library.
Fields
sta_mode: StaModedelay_model_type: DelayModelTypeChoose between using NDLM or a constant delay.
library: &'a LibertyTimingLibrary<'a>pin_capacitances: FnvHashMap<N::PinId, NDLMOutputLoad>Table for quickly finding the input capacitance of a pin.
Capacitance is available also in pin_data but access might be faster using this field.
pin_data: FnvHashMap<N::PinId, &'a Pin>Lookup-table for pin data (capacitance, delay arcs, constraint arcs, …).
ordered_pins: FnvHashMap<N::CellId, Vec<N::PinId>>Cache the pin ordering for all the cells.
warn_negative_slew: OnceWarn once about negative slew.
warn_negative_delay: OnceImplementations
sourceimpl<'a, N: NetlistBase> NDLMCellModel<'a, N>
impl<'a, N: NetlistBase> NDLMCellModel<'a, N>
sourcepub fn new(library: &'a LibertyTimingLibrary<'_>, netlist: &N) -> Self
pub fn new(library: &'a LibertyTimingLibrary<'_>, netlist: &N) -> Self
Create a new NDLM cell model based on a liberty library.
sourcepub fn set_delay_model_type(&mut self, model_type: DelayModelType)
pub fn set_delay_model_type(&mut self, model_type: DelayModelType)
Choose between NDLM and constant delays.
fn init(&mut self, netlist: &N)
sourcefn init_capacitance_table(&mut self, netlist: &N)
fn init_capacitance_table(&mut self, netlist: &N)
Create a lookup-table for the default pin capacitances.