Struct libreda_sta::SimpleSTA
source · pub struct SimpleSTA<'a, N, Lib, State>where
N: NetlistBase,
Lib: DelayBase + LoadBase + ConstraintBase,{
pub(crate) netlist: N,
pub(crate) top_cell: N::CellId,
pub(crate) library: &'a Lib,
pub(crate) input_signals: HashMap<N::PinId, Lib::Signal>,
pub(crate) output_loads: HashMap<N::PinId, Lib::Load>,
pub(crate) required_output_signals: HashMap<N::PinId, Lib::RequiredSignal>,
pub(crate) clocks: HashMap<TerminalId<N>, ClockDefinition<Lib::Signal>>,
pub(crate) timing_graph: TimingGraph<N, Lib>,
pub(crate) generation: u32,
pub(crate) _netlist_type: PhantomData<N>,
pub(crate) _state: PhantomData<State>,
}Expand description
Simple static timing analysis engine.
Fields
netlist: Ntop_cell: N::CellIdlibrary: &'a Libinput_signals: HashMap<N::PinId, Lib::Signal>output_loads: HashMap<N::PinId, Lib::Load>required_output_signals: HashMap<N::PinId, Lib::RequiredSignal>clocks: HashMap<TerminalId<N>, ClockDefinition<Lib::Signal>>timing_graph: TimingGraph<N, Lib>generation: u32Count the number of timing updates. Used to efficiently mark nodes in the timing graph which are relevant for the current incremental upgrade. Used to distinguish between the first full update (needs more initialization) and subsequent incremental updates.
_netlist_type: PhantomData<N>_state: PhantomData<State>Implementations
sourceimpl<'a, N, Lib, S> SimpleSTA<'a, N, Lib, S>where
N: NetlistBase,
Lib: DelayBase + ConstraintBase,
impl<'a, N, Lib, S> SimpleSTA<'a, N, Lib, S>where N: NetlistBase, Lib: DelayBase + ConstraintBase,
sourcepub fn into_inner(self) -> N
pub fn into_inner(self) -> N
Get ownership of the netlist data.
pub(crate) fn top_cell_ref(&self) -> CellRef<'_, N>
sourceimpl<'a, N, Lib> SimpleSTA<'a, N, Lib, TimingAvailable>where
N: NetlistBase,
Lib: DelayBase + ConstraintBase,
impl<'a, N, Lib> SimpleSTA<'a, N, Lib, TimingAvailable>where N: NetlistBase, Lib: DelayBase + ConstraintBase,
sourcepub fn to_modifiable(self) -> SimpleSTA<'a, N, Lib, Modifiable>
pub fn to_modifiable(self) -> SimpleSTA<'a, N, Lib, Modifiable>
Convert to modifiable state. Call this function to modify the timing analysis settings or the netlist.
sourceimpl<'a, N, Lib> SimpleSTA<'a, N, Lib, Modifiable>where
N: NetlistBaseMT,
Lib: CellLoadModel<N> + CellDelayModel<N> + CellConstraintModel<N> + Sync,
impl<'a, N, Lib> SimpleSTA<'a, N, Lib, Modifiable>where N: NetlistBaseMT, Lib: CellLoadModel<N> + CellDelayModel<N> + CellConstraintModel<N> + Sync,
sourcepub fn update_timing(
self
) -> Result<SimpleSTA<'a, N, Lib, TimingAvailable>, (StaError, Self)>
pub fn update_timing( self ) -> Result<SimpleSTA<'a, N, Lib, TimingAvailable>, (StaError, Self)>
Compute the timing information.
On success, returns the STA engine in TimingAvailable mode where
timing queries are enabled.
On error, returns a tuple with an error code and the STA engine in Modifiable mode.
sourceimpl<'a, N, Lib> SimpleSTA<'a, N, Lib, Modifiable>where
N: NetlistBase,
Lib: CellLoadModel<N> + CellDelayModel<N> + CellConstraintModel<N>,
impl<'a, N, Lib> SimpleSTA<'a, N, Lib, Modifiable>where N: NetlistBase, Lib: CellLoadModel<N> + CellDelayModel<N> + CellConstraintModel<N>,
sourcepub fn new(
netlist: N,
top_cell: N::CellId,
cell_timing_library: &'a Lib
) -> Result<Self, StaError>
pub fn new( netlist: N, top_cell: N::CellId, cell_timing_library: &'a Lib ) -> Result<Self, StaError>
Create a new static timing analysis engine which analyzes the given netlist using timing information of the cells from the given library.
pub(crate) fn init(&mut self) -> Result<(), StaError>
sourcepub fn set_input_signal(
&mut self,
primary_input: N::PinId,
signal: Lib::Signal
) -> Result<(), StaError>
pub fn set_input_signal( &mut self, primary_input: N::PinId, signal: Lib::Signal ) -> Result<(), StaError>
Set the signal at a primary input.
sourcepub fn set_output_load(
&mut self,
primary_output: N::PinId,
load: Lib::Load
) -> Result<(), StaError>
pub fn set_output_load( &mut self, primary_output: N::PinId, load: Lib::Load ) -> Result<(), StaError>
Set the load attached to a primary output.
sourcepub fn set_required_output_signal(
&mut self,
primary_output: N::PinId,
required_signal: Lib::RequiredSignal
) -> Result<(), StaError>
pub fn set_required_output_signal( &mut self, primary_output: N::PinId, required_signal: Lib::RequiredSignal ) -> Result<(), StaError>
Specify the timing constraint of a primary output.
sourcepub fn create_clock(
&mut self,
clock_pin: TerminalId<N>,
clock_definition: ClockDefinition<Lib::Signal>
) -> Result<(), StaError>
pub fn create_clock( &mut self, clock_pin: TerminalId<N>, clock_definition: ClockDefinition<Lib::Signal> ) -> Result<(), StaError>
Specify a clock source.
sourcepub(crate) fn build_timing_graph(&mut self) -> Result<(), StaError>
pub(crate) fn build_timing_graph(&mut self) -> Result<(), StaError>
Create graph of delay arcs.
sourcepub(crate) fn init_input_signals(&mut self) -> Result<(), StaError>
pub(crate) fn init_input_signals(&mut self) -> Result<(), StaError>
Copy the defined input signals into the nodes of the timing graph.
sourcepub(crate) fn init_required_output_signals(&mut self) -> Result<(), StaError>
pub(crate) fn init_required_output_signals(&mut self) -> Result<(), StaError>
Copy the specified output signals into the timing graph.
sourcepub(crate) fn init_output_loads(&mut self) -> Result<(), StaError>
pub(crate) fn init_output_loads(&mut self) -> Result<(), StaError>
Copy the specified output loads into the timing graph.
pub(crate) fn init_clock_signals(&mut self) -> Result<(), StaError>
sourcepub(crate) fn propagate_signals(
&mut self,
net_loads: &FnvHashMap<N::NetId, Lib::Load>
) -> Result<(), StaError>where
Lib: Sync,
N: NetlistBaseMT,
pub(crate) fn propagate_signals( &mut self, net_loads: &FnvHashMap<N::NetId, Lib::Load> ) -> Result<(), StaError>where Lib: Sync, N: NetlistBaseMT,
Compute actual and required arival times.
pub(crate) fn toposort_delay_graph( &self ) -> Result<Vec<TerminalId<N>>, StaError>
pub(crate) fn debug_print_actual_signals(&self)
pub(crate) fn debug_print_timing_graph(&self)
sourcepub(crate) fn run_sta(&mut self) -> Result<(), StaError>where
Lib: Sync,
N: NetlistBaseMT,
pub(crate) fn run_sta(&mut self) -> Result<(), StaError>where Lib: Sync, N: NetlistBaseMT,
Do static timing analysis of the top cell.
A single clock is allowed and specified with clock_input.
Results are just printed on stdout.
sourcepub(crate) fn check_library(&self) -> Result<(), StaError>
pub(crate) fn check_library(&self) -> Result<(), StaError>
Check that all cells in the circuit are covered by the library. TODO: Maybe move this into the library adapter.
sourcepub(crate) fn check_clock_sources(&self) -> Result<(), StaError>
pub(crate) fn check_clock_sources(&self) -> Result<(), StaError>
Do some sanity checks.