Trait libreda_sta::traits::cell_load_model::CellLoadModel

source ·
pub trait CellLoadModel<N: NetlistIds>: TimingBase + LoadBase + CellModel<N> {
    // Required methods
    fn input_pin_load(
        &self,
        input_pin: &N::PinId,
        other_inputs: &impl Fn(&N::PinId) -> Option<Self::LogicValue>
    ) -> Self::Load;
    fn zero(&self) -> Self::Load;
}
Abstraction of electrical loads created by input pins.

Required Methods

source

fn input_pin_load( &self, input_pin: &N::PinId, other_inputs: &impl Fn(&N::PinId) -> Option<Self::LogicValue> ) -> Self::Load

Get the load created by a pin, typically its capacitance.

source

fn zero(&self) -> Self::Load

Return a value representing no load at all (zero capacitance for example).

Object Safety

This trait is not object safe.

Implementations on Foreign Types

source

impl<N: NetlistIds, CLM: CellLoadModel<N> + ?Sized> CellLoadModel<N> for &CLM

source

fn input_pin_load( &self, input_pin: &N::PinId, other_inputs: &impl Fn(&N::PinId) -> Option<Self::LogicValue> ) -> Self::Load

source

fn zero(&self) -> Self::Load

Implementors