Trait libreda_sta::traits::cell_model::CellModel

source ·
pub trait CellModel<N: NetlistIds> {
    // Required method
    fn ordered_pins(&self, cell: &N::CellId) -> Vec<N::PinId>;
}
Base trait for cell delay and constraint models.

Required Methods

source

fn ordered_pins(&self, cell: &N::CellId) -> Vec<N::PinId>

Get the cell pins in a consistent ordering. The same ordering will be used for passing input signals to the cell delay model or cell constraint model.

Implementations on Foreign Types

source

impl<N: NetlistIds, CM: CellModel<N> + ?Sized> CellModel<N> for &CM

source

fn ordered_pins(&self, cell: &N::CellId) -> Vec<N::PinId>

Implementors

source

impl<'a, N: NetlistBase> CellModel<N> for NDLMCellModel<'a, N>

source

impl<M, N> CellModel<N> for ClockAwareModel<M>
where N: NetlistBase, M: CellModel<N>,