Trait libreda_sta::traits::cell_model::CellModel
source · pub trait CellModel<N: NetlistIds> {
// Required method
fn ordered_pins(&self, cell: &N::CellId) -> Vec<N::PinId>;
}Expand description
Base trait for cell delay and constraint models.
Required Methods
sourcefn ordered_pins(&self, cell: &N::CellId) -> Vec<N::PinId>
fn ordered_pins(&self, cell: &N::CellId) -> Vec<N::PinId>
Get the cell pins in a consistent ordering. The same ordering will be used for passing input signals to the cell delay model or cell constraint model.