Trait libreda_sta::traits::timing_base::TimingBase
source · pub trait TimingBase: LoadBase {
type Signal: Signal<LogicValue = Self::LogicValue>;
type LogicValue: Copy + Clone + Debug + Default + Sync + Send + From<bool> + TryInto<bool>;
}Expand description
Defines the concept of signals (e.g. slew rates and actual arrival times) and output loads (e.g. load capacitance).
Required Associated Types
sourcetype Signal: Signal<LogicValue = Self::LogicValue>
type Signal: Signal<LogicValue = Self::LogicValue>
Representation of signals at input or output pins. In case of the Non-linear delay model (NDLM) this could be a bundle of the slew rate and the delay but also the polarity of the signal. But this type could as well also be a statistical representation of a signal, e.g. a probability distribution of arrival times.
sourcetype LogicValue: Copy + Clone + Debug + Default + Sync + Send + From<bool> + TryInto<bool>
type LogicValue: Copy + Clone + Debug + Default + Sync + Send + From<bool> + TryInto<bool>
Type of logic value.
Typically this might be a three-valued type which represents logical 0, 1 and ‘unknown’.
The default is typically ‘unknown’.
This is used to specify static input signals when evaluating cell delays or constraints.
Implementations on Foreign Types
sourceimpl<TB: TimingBase + ?Sized> TimingBase for &TB
impl<TB: TimingBase + ?Sized> TimingBase for &TB
type Signal = <TB as TimingBase>::Signal
type Signal = <TB as TimingBase>::Signal
Representation of signals at input or output pins. In case of the Non-linear delay model (NDLM) this could be a bundle of the slew rate and the delay but also the polarity of the signal. But this type could as well also be a statistical representation of a signal, e.g. a probability distribution of arrival times.
type LogicValue = <TB as TimingBase>::LogicValue
type LogicValue = <TB as TimingBase>::LogicValue
Type of logic value.
Typically this might be a three-valued type which represents logical 0, 1 and ‘unknown’.
The default is typically ‘unknown’.
This is used to specify static input signals when evaluating cell delays or constraints.
Implementors
sourceimpl<'a, N: NetlistBase> TimingBase for NDLMCellModel<'a, N>
impl<'a, N: NetlistBase> TimingBase for NDLMCellModel<'a, N>
type Signal = NDLMSignal
type LogicValue = Logic3
sourceimpl<D> TimingBase for ZeroInterconnectDelayModel<D>where
D: TimingBase,
impl<D> TimingBase for ZeroInterconnectDelayModel<D>where
D: TimingBase,
type Signal = <D as TimingBase>::Signal
type LogicValue = <D as TimingBase>::LogicValue
sourceimpl<M> TimingBase for ClockAwareInterconnectModel<M>where
M: TimingBase,
impl<M> TimingBase for ClockAwareInterconnectModel<M>where
M: TimingBase,
Delegate trait implementation to the inner model.